# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/metrics.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import interaction_event_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_interaction__event__type__pb2
from google.ads.google_ads.v1.proto.enums import quality_score_bucket_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_quality__score__bucket__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/metrics.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\014MetricsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n2google/ads/googleads_v1/proto/common/metrics.proto\x12\x1egoogle.ads.googleads.v1.common\x1a@google/ads/googleads_v1/proto/enums/interaction_event_type.proto\x1a>google/ads/googleads_v1/proto/enums/quality_score_bucket.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb3\x39\n\x07Metrics\x12H\n\"absolute_top_impression_percentage\x18_ \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0f\x61\x63tive_view_cpm\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0f\x61\x63tive_view_ctr\x18O \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x17\x61\x63tive_view_impressions\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x19\x61\x63tive_view_measurability\x18` \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12G\n\"active_view_measurable_cost_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12G\n\"active_view_measurable_impressions\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x17\x61\x63tive_view_viewability\x18\x61 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12L\n&all_conversions_from_interactions_rate\x18\x41 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x15\x61ll_conversions_value\x18\x42 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0f\x61ll_conversions\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x44\n\x1e\x61ll_conversions_value_per_cost\x18> \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12H\n\"all_conversions_from_click_to_call\x18v \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x45\n\x1f\x61ll_conversions_from_directions\x18w \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12]\n7all_conversions_from_interactions_value_per_interaction\x18\x43 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12?\n\x19\x61ll_conversions_from_menu\x18x \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12@\n\x1a\x61ll_conversions_from_order\x18y \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12K\n%all_conversions_from_other_engagement\x18z \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x46\n all_conversions_from_store_visit\x18{ \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12H\n\"all_conversions_from_store_website\x18| \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0c\x61verage_cost\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x61verage_cpc\x18\t \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x61verage_cpe\x18\x62 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x61verage_cpm\x18\n \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x61verage_cpv\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x37\n\x11\x61verage_frequency\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x38\n\x12\x61verage_page_views\x18\x63 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x10\x61verage_position\x18\r \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x14\x61verage_time_on_site\x18T \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12?\n\x19\x62\x65nchmark_average_max_cpc\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\rbenchmark_ctr\x18M \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x62ounce_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x06\x63licks\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0f\x63ombined_clicks\x18s \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x19\x63ombined_clicks_per_query\x18t \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x10\x63ombined_queries\x18u \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12J\n$content_budget_lost_impression_share\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\x18\x63ontent_impression_share\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12P\n*conversion_last_received_request_date_time\x18I \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1f\x63onversion_last_conversion_date\x18J \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12H\n\"content_rank_lost_impression_share\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12H\n\"conversions_from_interactions_rate\x18\x45 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x37\n\x11\x63onversions_value\x18\x46 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12@\n\x1a\x63onversions_value_per_cost\x18G \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12Y\n3conversions_from_interactions_value_per_interaction\x18H \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0b\x63onversions\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x63ost_micros\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x18\x63ost_per_all_conversions\x18\x44 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x39\n\x13\x63ost_per_conversion\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12R\n,cost_per_current_model_attributed_conversion\x18j \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\x18\x63ross_device_conversions\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12)\n\x03\x63tr\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n$current_model_attributed_conversions\x18\x65 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x61\n;current_model_attributed_conversions_from_interactions_rate\x18\x66 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12r\nLcurrent_model_attributed_conversions_from_interactions_value_per_interaction\x18g \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12P\n*current_model_attributed_conversions_value\x18h \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12Y\n3current_model_attributed_conversions_value_per_cost\x18i \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0f\x65ngagement_rate\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x65ngagements\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x45\n\x1fhotel_average_lead_value_micros\x18K \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12s\n!historical_creative_quality_score\x18P \x01(\x0e\x32H.google.ads.googleads.v1.enums.QualityScoreBucketEnum.QualityScoreBucket\x12w\n%historical_landing_page_quality_score\x18Q \x01(\x0e\x32H.google.ads.googleads.v1.enums.QualityScoreBucketEnum.QualityScoreBucket\x12=\n\x18historical_quality_score\x18R \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12q\n\x1fhistorical_search_predicted_ctr\x18S \x01(\x0e\x32H.google.ads.googleads.v1.enums.QualityScoreBucketEnum.QualityScoreBucket\x12\x33\n\x0egmail_forwards\x18U \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0bgmail_saves\x18V \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16gmail_secondary_clicks\x18W \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x10impression_reach\x18$ \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x41\n\x1cimpressions_from_store_reach\x18} \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0bimpressions\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x10interaction_rate\x18& \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0cinteractions\x18\' \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12m\n\x17interaction_event_types\x18\x64 \x03(\x0e\x32L.google.ads.googleads.v1.enums.InteractionEventTypeEnum.InteractionEventType\x12\x38\n\x12invalid_click_rate\x18( \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\x0einvalid_clicks\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12G\n!mobile_friendly_clicks_percentage\x18m \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\x0eorganic_clicks\x18n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x18organic_clicks_per_query\x18o \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x38\n\x13organic_impressions\x18p \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1dorganic_impressions_per_query\x18q \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x34\n\x0forganic_queries\x18r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x14percent_new_visitors\x18* \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0bphone_calls\x18+ \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11phone_impressions\x18, \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x12phone_through_rate\x18- \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0crelative_ctr\x18. \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n$search_absolute_top_impression_share\x18N \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12V\n0search_budget_lost_absolute_top_impression_share\x18X \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12I\n#search_budget_lost_impression_share\x18/ \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12M\n\'search_budget_lost_top_impression_share\x18Y \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x38\n\x12search_click_share\x18\x30 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12I\n#search_exact_match_impression_share\x18\x31 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12=\n\x17search_impression_share\x18\x32 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12T\n.search_rank_lost_absolute_top_impression_share\x18Z \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12G\n!search_rank_lost_impression_share\x18\x33 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12K\n%search_rank_lost_top_impression_share\x18[ \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x41\n\x1bsearch_top_impression_share\x18\\ \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0bspeed_score\x18k \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x19top_impression_percentage\x18] \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12V\n0valid_accelerated_mobile_pages_clicks_percentage\x18l \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12?\n\x19value_per_all_conversions\x18\x34 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x14value_per_conversion\x18\x35 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12S\n-value_per_current_model_attributed_conversion\x18^ \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12=\n\x17video_quartile_100_rate\x18\x36 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x16video_quartile_25_rate\x18\x37 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x16video_quartile_50_rate\x18\x38 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x16video_quartile_75_rate\x18\x39 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0fvideo_view_rate\x18: \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0bvideo_views\x18; \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18view_through_conversions\x18< \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\xe7\x01\n\"com.google.ads.googleads.v1.commonB\x0cMetricsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_interaction__event__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_quality__score__bucket__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='google.ads.googleads.v1.common.Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='absolute_top_impression_percentage', full_name='google.ads.googleads.v1.common.Metrics.absolute_top_impression_percentage', index=0,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_view_cpm', full_name='google.ads.googleads.v1.common.Metrics.active_view_cpm', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_view_ctr', full_name='google.ads.googleads.v1.common.Metrics.active_view_ctr', index=2,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_view_impressions', full_name='google.ads.googleads.v1.common.Metrics.active_view_impressions', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_view_measurability', full_name='google.ads.googleads.v1.common.Metrics.active_view_measurability', index=4,
      number=96, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_view_measurable_cost_micros', full_name='google.ads.googleads.v1.common.Metrics.active_view_measurable_cost_micros', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_view_measurable_impressions', full_name='google.ads.googleads.v1.common.Metrics.active_view_measurable_impressions', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_view_viewability', full_name='google.ads.googleads.v1.common.Metrics.active_view_viewability', index=7,
      number=97, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_interactions_rate', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_interactions_rate', index=8,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_value', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_value', index=9,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions', full_name='google.ads.googleads.v1.common.Metrics.all_conversions', index=10,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_value_per_cost', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_value_per_cost', index=11,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_click_to_call', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_click_to_call', index=12,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_directions', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_directions', index=13,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_interactions_value_per_interaction', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_interactions_value_per_interaction', index=14,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_menu', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_menu', index=15,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_order', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_order', index=16,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_other_engagement', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_other_engagement', index=17,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_store_visit', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_store_visit', index=18,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_conversions_from_store_website', full_name='google.ads.googleads.v1.common.Metrics.all_conversions_from_store_website', index=19,
      number=124, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cost', full_name='google.ads.googleads.v1.common.Metrics.average_cost', index=20,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpc', full_name='google.ads.googleads.v1.common.Metrics.average_cpc', index=21,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpe', full_name='google.ads.googleads.v1.common.Metrics.average_cpe', index=22,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpm', full_name='google.ads.googleads.v1.common.Metrics.average_cpm', index=23,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpv', full_name='google.ads.googleads.v1.common.Metrics.average_cpv', index=24,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_frequency', full_name='google.ads.googleads.v1.common.Metrics.average_frequency', index=25,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_page_views', full_name='google.ads.googleads.v1.common.Metrics.average_page_views', index=26,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_position', full_name='google.ads.googleads.v1.common.Metrics.average_position', index=27,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_time_on_site', full_name='google.ads.googleads.v1.common.Metrics.average_time_on_site', index=28,
      number=84, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='benchmark_average_max_cpc', full_name='google.ads.googleads.v1.common.Metrics.benchmark_average_max_cpc', index=29,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='benchmark_ctr', full_name='google.ads.googleads.v1.common.Metrics.benchmark_ctr', index=30,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bounce_rate', full_name='google.ads.googleads.v1.common.Metrics.bounce_rate', index=31,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clicks', full_name='google.ads.googleads.v1.common.Metrics.clicks', index=32,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combined_clicks', full_name='google.ads.googleads.v1.common.Metrics.combined_clicks', index=33,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combined_clicks_per_query', full_name='google.ads.googleads.v1.common.Metrics.combined_clicks_per_query', index=34,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combined_queries', full_name='google.ads.googleads.v1.common.Metrics.combined_queries', index=35,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_budget_lost_impression_share', full_name='google.ads.googleads.v1.common.Metrics.content_budget_lost_impression_share', index=36,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_impression_share', full_name='google.ads.googleads.v1.common.Metrics.content_impression_share', index=37,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_last_received_request_date_time', full_name='google.ads.googleads.v1.common.Metrics.conversion_last_received_request_date_time', index=38,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_last_conversion_date', full_name='google.ads.googleads.v1.common.Metrics.conversion_last_conversion_date', index=39,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_rank_lost_impression_share', full_name='google.ads.googleads.v1.common.Metrics.content_rank_lost_impression_share', index=40,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_from_interactions_rate', full_name='google.ads.googleads.v1.common.Metrics.conversions_from_interactions_rate', index=41,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_value', full_name='google.ads.googleads.v1.common.Metrics.conversions_value', index=42,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_value_per_cost', full_name='google.ads.googleads.v1.common.Metrics.conversions_value_per_cost', index=43,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions_from_interactions_value_per_interaction', full_name='google.ads.googleads.v1.common.Metrics.conversions_from_interactions_value_per_interaction', index=44,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions', full_name='google.ads.googleads.v1.common.Metrics.conversions', index=45,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v1.common.Metrics.cost_micros', index=46,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_per_all_conversions', full_name='google.ads.googleads.v1.common.Metrics.cost_per_all_conversions', index=47,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_per_conversion', full_name='google.ads.googleads.v1.common.Metrics.cost_per_conversion', index=48,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_per_current_model_attributed_conversion', full_name='google.ads.googleads.v1.common.Metrics.cost_per_current_model_attributed_conversion', index=49,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cross_device_conversions', full_name='google.ads.googleads.v1.common.Metrics.cross_device_conversions', index=50,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ctr', full_name='google.ads.googleads.v1.common.Metrics.ctr', index=51,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_model_attributed_conversions', full_name='google.ads.googleads.v1.common.Metrics.current_model_attributed_conversions', index=52,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_model_attributed_conversions_from_interactions_rate', full_name='google.ads.googleads.v1.common.Metrics.current_model_attributed_conversions_from_interactions_rate', index=53,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_model_attributed_conversions_from_interactions_value_per_interaction', full_name='google.ads.googleads.v1.common.Metrics.current_model_attributed_conversions_from_interactions_value_per_interaction', index=54,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_model_attributed_conversions_value', full_name='google.ads.googleads.v1.common.Metrics.current_model_attributed_conversions_value', index=55,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_model_attributed_conversions_value_per_cost', full_name='google.ads.googleads.v1.common.Metrics.current_model_attributed_conversions_value_per_cost', index=56,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engagement_rate', full_name='google.ads.googleads.v1.common.Metrics.engagement_rate', index=57,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engagements', full_name='google.ads.googleads.v1.common.Metrics.engagements', index=58,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_average_lead_value_micros', full_name='google.ads.googleads.v1.common.Metrics.hotel_average_lead_value_micros', index=59,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historical_creative_quality_score', full_name='google.ads.googleads.v1.common.Metrics.historical_creative_quality_score', index=60,
      number=80, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historical_landing_page_quality_score', full_name='google.ads.googleads.v1.common.Metrics.historical_landing_page_quality_score', index=61,
      number=81, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historical_quality_score', full_name='google.ads.googleads.v1.common.Metrics.historical_quality_score', index=62,
      number=82, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historical_search_predicted_ctr', full_name='google.ads.googleads.v1.common.Metrics.historical_search_predicted_ctr', index=63,
      number=83, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gmail_forwards', full_name='google.ads.googleads.v1.common.Metrics.gmail_forwards', index=64,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gmail_saves', full_name='google.ads.googleads.v1.common.Metrics.gmail_saves', index=65,
      number=86, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gmail_secondary_clicks', full_name='google.ads.googleads.v1.common.Metrics.gmail_secondary_clicks', index=66,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impression_reach', full_name='google.ads.googleads.v1.common.Metrics.impression_reach', index=67,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impressions_from_store_reach', full_name='google.ads.googleads.v1.common.Metrics.impressions_from_store_reach', index=68,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v1.common.Metrics.impressions', index=69,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interaction_rate', full_name='google.ads.googleads.v1.common.Metrics.interaction_rate', index=70,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='google.ads.googleads.v1.common.Metrics.interactions', index=71,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interaction_event_types', full_name='google.ads.googleads.v1.common.Metrics.interaction_event_types', index=72,
      number=100, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid_click_rate', full_name='google.ads.googleads.v1.common.Metrics.invalid_click_rate', index=73,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid_clicks', full_name='google.ads.googleads.v1.common.Metrics.invalid_clicks', index=74,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_friendly_clicks_percentage', full_name='google.ads.googleads.v1.common.Metrics.mobile_friendly_clicks_percentage', index=75,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organic_clicks', full_name='google.ads.googleads.v1.common.Metrics.organic_clicks', index=76,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organic_clicks_per_query', full_name='google.ads.googleads.v1.common.Metrics.organic_clicks_per_query', index=77,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organic_impressions', full_name='google.ads.googleads.v1.common.Metrics.organic_impressions', index=78,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organic_impressions_per_query', full_name='google.ads.googleads.v1.common.Metrics.organic_impressions_per_query', index=79,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organic_queries', full_name='google.ads.googleads.v1.common.Metrics.organic_queries', index=80,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_new_visitors', full_name='google.ads.googleads.v1.common.Metrics.percent_new_visitors', index=81,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_calls', full_name='google.ads.googleads.v1.common.Metrics.phone_calls', index=82,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_impressions', full_name='google.ads.googleads.v1.common.Metrics.phone_impressions', index=83,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_through_rate', full_name='google.ads.googleads.v1.common.Metrics.phone_through_rate', index=84,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_ctr', full_name='google.ads.googleads.v1.common.Metrics.relative_ctr', index=85,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_absolute_top_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_absolute_top_impression_share', index=86,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_budget_lost_absolute_top_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_budget_lost_absolute_top_impression_share', index=87,
      number=88, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_budget_lost_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_budget_lost_impression_share', index=88,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_budget_lost_top_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_budget_lost_top_impression_share', index=89,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_click_share', full_name='google.ads.googleads.v1.common.Metrics.search_click_share', index=90,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_exact_match_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_exact_match_impression_share', index=91,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_impression_share', index=92,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_rank_lost_absolute_top_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_rank_lost_absolute_top_impression_share', index=93,
      number=90, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_rank_lost_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_rank_lost_impression_share', index=94,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_rank_lost_top_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_rank_lost_top_impression_share', index=95,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_top_impression_share', full_name='google.ads.googleads.v1.common.Metrics.search_top_impression_share', index=96,
      number=92, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed_score', full_name='google.ads.googleads.v1.common.Metrics.speed_score', index=97,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_impression_percentage', full_name='google.ads.googleads.v1.common.Metrics.top_impression_percentage', index=98,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valid_accelerated_mobile_pages_clicks_percentage', full_name='google.ads.googleads.v1.common.Metrics.valid_accelerated_mobile_pages_clicks_percentage', index=99,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_per_all_conversions', full_name='google.ads.googleads.v1.common.Metrics.value_per_all_conversions', index=100,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_per_conversion', full_name='google.ads.googleads.v1.common.Metrics.value_per_conversion', index=101,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_per_current_model_attributed_conversion', full_name='google.ads.googleads.v1.common.Metrics.value_per_current_model_attributed_conversion', index=102,
      number=94, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_100_rate', full_name='google.ads.googleads.v1.common.Metrics.video_quartile_100_rate', index=103,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_25_rate', full_name='google.ads.googleads.v1.common.Metrics.video_quartile_25_rate', index=104,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_50_rate', full_name='google.ads.googleads.v1.common.Metrics.video_quartile_50_rate', index=105,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_quartile_75_rate', full_name='google.ads.googleads.v1.common.Metrics.video_quartile_75_rate', index=106,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_view_rate', full_name='google.ads.googleads.v1.common.Metrics.video_view_rate', index=107,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_views', full_name='google.ads.googleads.v1.common.Metrics.video_views', index=108,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_through_conversions', full_name='google.ads.googleads.v1.common.Metrics.view_through_conversions', index=109,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=7626,
)

_METRICS.fields_by_name['absolute_top_impression_percentage'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['active_view_cpm'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['active_view_ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['active_view_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['active_view_measurability'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['active_view_measurable_cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['active_view_measurable_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['active_view_viewability'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_interactions_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_value_per_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_click_to_call'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_directions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_interactions_value_per_interaction'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_menu'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_order'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_other_engagement'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_store_visit'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['all_conversions_from_store_website'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cpc'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cpe'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cpm'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_cpv'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_frequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_page_views'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_position'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['average_time_on_site'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['benchmark_average_max_cpc'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['benchmark_ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['bounce_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['combined_clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['combined_clicks_per_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['combined_queries'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['content_budget_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['content_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversion_last_received_request_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_METRICS.fields_by_name['conversion_last_conversion_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_METRICS.fields_by_name['content_rank_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_from_interactions_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_value_per_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions_from_interactions_value_per_interaction'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['cost_per_all_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['cost_per_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['cost_per_current_model_attributed_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['cross_device_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['current_model_attributed_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['current_model_attributed_conversions_from_interactions_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['current_model_attributed_conversions_from_interactions_value_per_interaction'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['current_model_attributed_conversions_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['current_model_attributed_conversions_value_per_cost'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['engagement_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['engagements'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['hotel_average_lead_value_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['historical_creative_quality_score'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_quality__score__bucket__pb2._QUALITYSCOREBUCKETENUM_QUALITYSCOREBUCKET
_METRICS.fields_by_name['historical_landing_page_quality_score'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_quality__score__bucket__pb2._QUALITYSCOREBUCKETENUM_QUALITYSCOREBUCKET
_METRICS.fields_by_name['historical_quality_score'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['historical_search_predicted_ctr'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_quality__score__bucket__pb2._QUALITYSCOREBUCKETENUM_QUALITYSCOREBUCKET
_METRICS.fields_by_name['gmail_forwards'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['gmail_saves'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['gmail_secondary_clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['impression_reach'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['impressions_from_store_reach'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['interaction_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['interactions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['interaction_event_types'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_interaction__event__type__pb2._INTERACTIONEVENTTYPEENUM_INTERACTIONEVENTTYPE
_METRICS.fields_by_name['invalid_click_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['invalid_clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['mobile_friendly_clicks_percentage'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['organic_clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['organic_clicks_per_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['organic_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['organic_impressions_per_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['organic_queries'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['percent_new_visitors'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['phone_calls'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['phone_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['phone_through_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['relative_ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_absolute_top_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_budget_lost_absolute_top_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_budget_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_budget_lost_top_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_click_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_exact_match_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_rank_lost_absolute_top_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_rank_lost_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_rank_lost_top_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['search_top_impression_share'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['speed_score'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['top_impression_percentage'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['valid_accelerated_mobile_pages_clicks_percentage'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['value_per_all_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['value_per_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['value_per_current_model_attributed_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_100_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_25_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_50_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_quartile_75_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_view_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICS.fields_by_name['video_views'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_METRICS.fields_by_name['view_through_conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), dict(
  DESCRIPTOR = _METRICS,
  __module__ = 'google.ads.googleads_v1.proto.common.metrics_pb2'
  ,
  __doc__ = """Metrics data.
  
  
  Attributes:
      absolute_top_impression_percentage:
          The percent of your ad impressions that are shown as the very
          first ad above the organic search results.
      active_view_cpm:
          Average cost of viewable impressions
          (``active_view_impressions``).
      active_view_ctr:
          Active view measurable clicks divided by active view viewable
          impressions. This metric is reported only for display network.
      active_view_impressions:
          A measurement of how often your ad has become viewable on a
          Display Network site.
      active_view_measurability:
          The ratio of impressions that could be measured by Active View
          over the number of served impressions.
      active_view_measurable_cost_micros:
          The cost of the impressions you received that were measurable
          by Active View.
      active_view_measurable_impressions:
          The number of times your ads are appearing on placements in
          positions where they can be seen.
      active_view_viewability:
          The percentage of time when your ad appeared on an Active View
          enabled site (measurable impressions) and was viewable
          (viewable impressions).
      all_conversions_from_interactions_rate:
          All conversions from interactions (as oppose to view through
          conversions) divided by the number of ad interactions.
      all_conversions_value:
          The total value of all conversions.
      all_conversions:
          The total number of conversions. This only includes conversion
          actions which include\_in\_conversions\_metric attribute is
          set to true.
      all_conversions_value_per_cost:
          The value of all conversions divided by the total cost of ad
          interactions (such as clicks for text ads or views for video
          ads).
      all_conversions_from_click_to_call:
          The number of times people clicked the "Call" button to call a
          store during or after clicking an ad. This number doesn't
          include whether or not calls were connected, or the duration
          of any calls. This metric applies to feed items only.
      all_conversions_from_directions:
          The number of times people clicked a "Get directions" button
          to navigate to a store after clicking an ad. This metric
          applies to feed items only.
      all_conversions_from_interactions_value_per_interaction:
          The value of all conversions from interactions divided by the
          total number of interactions.
      all_conversions_from_menu:
          The number of times people clicked a link to view a store's
          menu after clicking an ad. This metric applies to feed items
          only.
      all_conversions_from_order:
          The number of times people placed an order at a store after
          clicking an ad. This metric applies to feed items only.
      all_conversions_from_other_engagement:
          The number of other conversions (for example, posting a review
          or saving a location for a store) that occurred after people
          clicked an ad. This metric applies to feed items only.
      all_conversions_from_store_visit:
          Estimated number of times people visited a store after
          clicking an ad. This metric applies to feed items only.
      all_conversions_from_store_website:
          The number of times that people were taken to a store's URL
          after clicking an ad. This metric applies to feed items only.
      average_cost:
          The average amount you pay per interaction. This amount is the
          total cost of your ads divided by the total number of
          interactions.
      average_cpc:
          The total cost of all clicks divided by the total number of
          clicks received.
      average_cpe:
          The average amount that you've been charged for an ad
          engagement. This amount is the total cost of all ad
          engagements divided by the total number of ad engagements.
      average_cpm:
          Average cost-per-thousand impressions (CPM).
      average_cpv:
          The average amount you pay each time someone views your ad.
          The average CPV is defined by the total cost of all ad views
          divided by the number of views.
      average_frequency:
          Average number of times a unique cookie was exposed to your ad
          over a given time period. Imported from Google Analytics.
      average_page_views:
          Average number of pages viewed per session.
      average_position:
          Your ad's position relative to those of other advertisers.
      average_time_on_site:
          Total duration of all sessions (in seconds) / number of
          sessions. Imported from Google Analytics.
      benchmark_average_max_cpc:
          An indication of how other advertisers are bidding on similar
          products.
      benchmark_ctr:
          An indication on how other advertisers' Shopping ads for
          similar products are performing based on how often people who
          see their ad click on it.
      bounce_rate:
          Percentage of clicks where the user only visited a single page
          on your site. Imported from Google Analytics.
      clicks:
          The number of clicks.
      combined_clicks:
          The number of times your ad or your site's listing in the
          unpaid results was clicked. See the help page at
          https://support.google.com/google-ads/answer/3097241 for
          details.
      combined_clicks_per_query:
          The number of times your ad or your site's listing in the
          unpaid results was clicked (combined\_clicks) divided by
          combined\_queries. See the help page at
          https://support.google.com/google-ads/answer/3097241 for
          details.
      combined_queries:
          The number of searches that returned pages from your site in
          the unpaid results or showed one of your text ads. See the
          help page at https://support.google.com/google-
          ads/answer/3097241 for details.
      content_budget_lost_impression_share:
          The estimated percent of times that your ad was eligible to
          show on the Display Network but didn't because your budget was
          too low. Note: Content budget lost impression share is
          reported in the range of 0 to 0.9. Any value above 0.9 is
          reported as 0.9001.
      content_impression_share:
          The impressions you've received on the Display Network divided
          by the estimated number of impressions you were eligible to
          receive. Note: Content impression share is reported in the
          range of 0.1 to 1. Any value below 0.1 is reported as 0.0999.
      conversion_last_received_request_date_time:
          The last date/time a conversion tag for this conversion action
          successfully fired and was seen by Google Ads. This firing
          event may not have been the result of an attributable
          conversion (e.g. because the tag was fired from a browser that
          did not previously click an ad from an appropriate
          advertiser). The date/time is in the customer's time zone.
      conversion_last_conversion_date:
          The date of the most recent conversion for this conversion
          action. The date is in the customer's time zone.
      content_rank_lost_impression_share:
          The estimated percentage of impressions on the Display Network
          that your ads didn't receive due to poor Ad Rank. Note:
          Content rank lost impression share is reported in the range of
          0 to 0.9. Any value above 0.9 is reported as 0.9001.
      conversions_from_interactions_rate:
          Conversions from interactions divided by the number of ad
          interactions (such as clicks for text ads or views for video
          ads). This only includes conversion actions which
          include\_in\_conversions\_metric attribute is set to true.
      conversions_value:
          The total value of conversions. This only includes conversion
          actions which include\_in\_conversions\_metric attribute is
          set to true.
      conversions_value_per_cost:
          The value of conversions divided by the cost of ad
          interactions. This only includes conversion actions which
          include\_in\_conversions\_metric attribute is set to true.
      conversions_from_interactions_value_per_interaction:
          The value of conversions from interactions divided by the
          number of ad interactions. This only includes conversion
          actions which include\_in\_conversions\_metric attribute is
          set to true.
      conversions:
          The number of conversions. This only includes conversion
          actions which include\_in\_conversions\_metric attribute is
          set to true.
      cost_micros:
          The sum of your cost-per-click (CPC) and cost-per-thousand
          impressions (CPM) costs during this period.
      cost_per_all_conversions:
          The cost of ad interactions divided by all conversions.
      cost_per_conversion:
          The cost of ad interactions divided by conversions. This only
          includes conversion actions which
          include\_in\_conversions\_metric attribute is set to true.
      cost_per_current_model_attributed_conversion:
          The cost of ad interactions divided by current model
          attributed conversions. This only includes conversion actions
          which include\_in\_conversions\_metric attribute is set to
          true.
      cross_device_conversions:
          Conversions from when a customer clicks on a Google Ads ad on
          one device, then converts on a different device or browser.
          Cross-device conversions are already included in
          all\_conversions.
      ctr:
          The number of clicks your ad receives (Clicks) divided by the
          number of times your ad is shown (Impressions).
      current_model_attributed_conversions:
          Shows how your historic conversions data would look under the
          attribution model you've currently selected. This only
          includes conversion actions which
          include\_in\_conversions\_metric attribute is set to true.
      current_model_attributed_conversions_from_interactions_rate:
          Current model attributed conversions from interactions divided
          by the number of ad interactions (such as clicks for text ads
          or views for video ads). This only includes conversion actions
          which include\_in\_conversions\_metric attribute is set to
          true.
      current_model_attributed_conversions_from_interactions_value_per_interaction:
          The value of current model attributed conversions from
          interactions divided by the number of ad interactions. This
          only includes conversion actions which
          include\_in\_conversions\_metric attribute is set to true.
      current_model_attributed_conversions_value:
          The total value of current model attributed conversions. This
          only includes conversion actions which
          include\_in\_conversions\_metric attribute is set to true.
      current_model_attributed_conversions_value_per_cost:
          The value of current model attributed conversions divided by
          the cost of ad interactions. This only includes conversion
          actions which include\_in\_conversions\_metric attribute is
          set to true.
      engagement_rate:
          How often people engage with your ad after it's shown to them.
          This is the number of ad expansions divided by the number of
          times your ad is shown.
      engagements:
          The number of engagements. An engagement occurs when a viewer
          expands your Lightbox ad. Also, in the future, other ad types
          may support engagement metrics.
      hotel_average_lead_value_micros:
          Average lead value of hotel.
      historical_creative_quality_score:
          The creative historical quality score.
      historical_landing_page_quality_score:
          The quality of historical landing page experience.
      historical_quality_score:
          The historical quality score.
      historical_search_predicted_ctr:
          The historical search predicted click through rate (CTR).
      gmail_forwards:
          The number of times the ad was forwarded to someone else as a
          message.
      gmail_saves:
          The number of times someone has saved your Gmail ad to their
          inbox as a message.
      gmail_secondary_clicks:
          The number of clicks to the landing page on the expanded state
          of Gmail ads.
      impression_reach:
          Number of unique cookies that were exposed to your ad over a
          given time period.
      impressions_from_store_reach:
          The number of times a store's location-based ad was shown.
          This metric applies to feed items only.
      impressions:
          Count of how often your ad has appeared on a search results
          page or website on the Google Network.
      interaction_rate:
          How often people interact with your ad after it is shown to
          them. This is the number of interactions divided by the number
          of times your ad is shown.
      interactions:
          The number of interactions. An interaction is the main user
          action associated with an ad format-clicks for text and
          shopping ads, views for video ads, and so on.
      interaction_event_types:
          The types of payable and free interactions.
      invalid_click_rate:
          The percentage of clicks filtered out of your total number of
          clicks (filtered + non-filtered clicks) during the reporting
          period.
      invalid_clicks:
          Number of clicks Google considers illegitimate and doesn't
          charge you for.
      mobile_friendly_clicks_percentage:
          The percentage of mobile clicks that go to a mobile-friendly
          page.
      organic_clicks:
          The number of times someone clicked your site's listing in the
          unpaid results for a particular query. See the help page at
          https://support.google.com/google-ads/answer/3097241 for
          details.
      organic_clicks_per_query:
          The number of times someone clicked your site's listing in the
          unpaid results (organic\_clicks) divided by the total number
          of searches that returned pages from your site
          (organic\_queries). See the help page at
          https://support.google.com/google-ads/answer/3097241 for
          details.
      organic_impressions:
          The number of listings for your site in the unpaid search
          results. See the help page at
          https://support.google.com/google-ads/answer/3097241 for
          details.
      organic_impressions_per_query:
          The number of times a page from your site was listed in the
          unpaid search results (organic\_impressions) divided by the
          number of searches returning your site's listing in the unpaid
          results (organic\_queries). See the help page at
          https://support.google.com/google-ads/answer/3097241 for
          details.
      organic_queries:
          The total number of searches that returned your site's listing
          in the unpaid results. See the help page at
          https://support.google.com/google-ads/answer/3097241 for
          details.
      percent_new_visitors:
          Percentage of first-time sessions (from people who had never
          visited your site before). Imported from Google Analytics.
      phone_calls:
          Number of offline phone calls.
      phone_impressions:
          Number of offline phone impressions.
      phone_through_rate:
          Number of phone calls received (phone\_calls) divided by the
          number of times your phone number is shown
          (phone\_impressions).
      relative_ctr:
          Your clickthrough rate (Ctr) divided by the average
          clickthrough rate of all advertisers on the websites that show
          your ads. Measures how your ads perform on Display Network
          sites compared to other ads on the same sites.
      search_absolute_top_impression_share:
          The percentage of the customer's Shopping or Search ad
          impressions that are shown in the most prominent Shopping
          position. See this Merchant Center article for details. Any
          value below 0.1 is reported as 0.0999.
      search_budget_lost_absolute_top_impression_share:
          The number estimating how often your ad wasn't the very first
          ad above the organic search results due to a low budget. Note:
          Search budget lost absolute top impression share is reported
          in the range of 0 to 0.9. Any value above 0.9 is reported as
          0.9001.
      search_budget_lost_impression_share:
          The estimated percent of times that your ad was eligible to
          show on the Search Network but didn't because your budget was
          too low. Note: Search budget lost impression share is reported
          in the range of 0 to 0.9. Any value above 0.9 is reported as
          0.9001.
      search_budget_lost_top_impression_share:
          The number estimating how often your ad didn't show anywhere
          above the organic search results due to a low budget. Note:
          Search budget lost top impression share is reported in the
          range of 0 to 0.9. Any value above 0.9 is reported as 0.9001.
      search_click_share:
          The number of clicks you've received on the Search Network
          divided by the estimated number of clicks you were eligible to
          receive. Note: Search click share is reported in the range of
          0.1 to 1. Any value below 0.1 is reported as 0.0999.
      search_exact_match_impression_share:
          The impressions you've received divided by the estimated
          number of impressions you were eligible to receive on the
          Search Network for search terms that matched your keywords
          exactly (or were close variants of your keyword), regardless
          of your keyword match types. Note: Search exact match
          impression share is reported in the range of 0.1 to 1. Any
          value below 0.1 is reported as 0.0999.
      search_impression_share:
          The impressions you've received on the Search Network divided
          by the estimated number of impressions you were eligible to
          receive. Note: Search impression share is reported in the
          range of 0.1 to 1. Any value below 0.1 is reported as 0.0999.
      search_rank_lost_absolute_top_impression_share:
          The number estimating how often your ad wasn't the very first
          ad above the organic search results due to poor Ad Rank. Note:
          Search rank lost absolute top impression share is reported in
          the range of 0 to 0.9. Any value above 0.9 is reported as
          0.9001.
      search_rank_lost_impression_share:
          The estimated percentage of impressions on the Search Network
          that your ads didn't receive due to poor Ad Rank. Note: Search
          rank lost impression share is reported in the range of 0 to
          0.9. Any value above 0.9 is reported as 0.9001.
      search_rank_lost_top_impression_share:
          The number estimating how often your ad didn't show anywhere
          above the organic search results due to poor Ad Rank. Note:
          Search rank lost top impression share is reported in the range
          of 0 to 0.9. Any value above 0.9 is reported as 0.9001.
      search_top_impression_share:
          The impressions you've received in the top location (anywhere
          above the organic search results) compared to the estimated
          number of impressions you were eligible to receive in the top
          location. Note: Search top impression share is reported in the
          range of 0.1 to 1. Any value below 0.1 is reported as 0.0999.
      speed_score:
          A measure of how quickly your page loads after clicks on your
          mobile ads. The score is a range from 1 to 10, 10 being the
          fastest.
      top_impression_percentage:
          The percent of your ad impressions that are shown anywhere
          above the organic search results.
      valid_accelerated_mobile_pages_clicks_percentage:
          The percentage of ad clicks to Accelerated Mobile Pages (AMP)
          landing pages that reach a valid AMP page.
      value_per_all_conversions:
          The value of all conversions divided by the number of all
          conversions.
      value_per_conversion:
          The value of conversions divided by the number of conversions.
          This only includes conversion actions which
          include\_in\_conversions\_metric attribute is set to true.
      value_per_current_model_attributed_conversion:
          The value of current model attributed conversions divided by
          the number of the conversions. This only includes conversion
          actions which include\_in\_conversions\_metric attribute is
          set to true.
      video_quartile_100_rate:
          Percentage of impressions where the viewer watched all of your
          video.
      video_quartile_25_rate:
          Percentage of impressions where the viewer watched 25% of your
          video.
      video_quartile_50_rate:
          Percentage of impressions where the viewer watched 50% of your
          video.
      video_quartile_75_rate:
          Percentage of impressions where the viewer watched 75% of your
          video.
      video_view_rate:
          The number of views your TrueView video ad receives divided by
          its number of impressions, including thumbnail impressions for
          TrueView in-display ads.
      video_views:
          The number of times your video ads were viewed.
      view_through_conversions:
          The total number of view-through conversions. These happen
          when a customer sees an image or rich media ad, then later
          completes a conversion on your site without interacting with
          (e.g., clicking on) another ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Metrics)
  ))
_sym_db.RegisterMessage(Metrics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/campaign_draft_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import campaign_draft_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/campaign_draft_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\031CampaignDraftServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v2/proto/services/campaign_draft_service.proto\x12 google.ads.googleads.v2.services\x1a<google/ads/googleads_v2/proto/resources/campaign_draft.proto\x1a\x1cgoogle/api/annotations.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\"0\n\x17GetCampaignDraftRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xb0\x01\n\x1bMutateCampaignDraftsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12L\n\noperations\x18\x02 \x03(\x0b\x32\x38.google.ads.googleads.v2.services.CampaignDraftOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"5\n\x1bPromoteCampaignDraftRequest\x12\x16\n\x0e\x63\x61mpaign_draft\x18\x01 \x01(\t\"\xf0\x01\n\x16\x43\x61mpaignDraftOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x42\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.CampaignDraftH\x00\x12\x42\n\x06update\x18\x02 \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.CampaignDraftH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"\x9f\x01\n\x1cMutateCampaignDraftsResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12L\n\x07results\x18\x02 \x03(\x0b\x32;.google.ads.googleads.v2.services.MutateCampaignDraftResult\"2\n\x19MutateCampaignDraftResult\x12\x15\n\rresource_name\x18\x01 \x01(\t\"c\n#ListCampaignDraftAsyncErrorsRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\"c\n$ListCampaignDraftAsyncErrorsResponse\x12\"\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x12.google.rpc.Status\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x98\x07\n\x14\x43\x61mpaignDraftService\x12\xb9\x01\n\x10GetCampaignDraft\x12\x39.google.ads.googleads.v2.services.GetCampaignDraftRequest\x1a\x30.google.ads.googleads.v2.resources.CampaignDraft\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v2/{resource_name=customers/*/campaignDrafts/*}\x12\xd5\x01\n\x14MutateCampaignDrafts\x12=.google.ads.googleads.v2.services.MutateCampaignDraftsRequest\x1a>.google.ads.googleads.v2.services.MutateCampaignDraftsResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v2/customers/{customer_id=*}/campaignDrafts:mutate:\x01*\x12\xd4\x01\n\x14PromoteCampaignDraft\x12=.google.ads.googleads.v2.services.PromoteCampaignDraftRequest\x1a\x1d.google.longrunning.Operation\"^\x82\xd3\xe4\x93\x02>\"9/v2/{campaign_draft=customers/*/campaignDrafts/*}:promote:\x01*\xca\x41\x17\n\x15google.protobuf.Empty\x12\xf7\x01\n\x1cListCampaignDraftAsyncErrors\x12\x45.google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsRequest\x1a\x46.google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/v2/{resource_name=customers/*/campaignDrafts/*}:listAsyncErrors\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x80\x02\n$com.google.ads.googleads.v2.servicesB\x19\x43\x61mpaignDraftServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETCAMPAIGNDRAFTREQUEST = _descriptor.Descriptor(
  name='GetCampaignDraftRequest',
  full_name='google.ads.googleads.v2.services.GetCampaignDraftRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetCampaignDraftRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=366,
)


_MUTATECAMPAIGNDRAFTSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignDraftsRequest',
  full_name='google.ads.googleads.v2.services.MutateCampaignDraftsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateCampaignDraftsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v2.services.MutateCampaignDraftsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.MutateCampaignDraftsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateCampaignDraftsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=545,
)


_PROMOTECAMPAIGNDRAFTREQUEST = _descriptor.Descriptor(
  name='PromoteCampaignDraftRequest',
  full_name='google.ads.googleads.v2.services.PromoteCampaignDraftRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='campaign_draft', full_name='google.ads.googleads.v2.services.PromoteCampaignDraftRequest.campaign_draft', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=600,
)


_CAMPAIGNDRAFTOPERATION = _descriptor.Descriptor(
  name='CampaignDraftOperation',
  full_name='google.ads.googleads.v2.services.CampaignDraftOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v2.services.CampaignDraftOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v2.services.CampaignDraftOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v2.services.CampaignDraftOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v2.services.CampaignDraftOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.CampaignDraftOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=603,
  serialized_end=843,
)


_MUTATECAMPAIGNDRAFTSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignDraftsResponse',
  full_name='google.ads.googleads.v2.services.MutateCampaignDraftsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.MutateCampaignDraftsResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.MutateCampaignDraftsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=1005,
)


_MUTATECAMPAIGNDRAFTRESULT = _descriptor.Descriptor(
  name='MutateCampaignDraftResult',
  full_name='google.ads.googleads.v2.services.MutateCampaignDraftResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateCampaignDraftResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1057,
)


_LISTCAMPAIGNDRAFTASYNCERRORSREQUEST = _descriptor.Descriptor(
  name='ListCampaignDraftAsyncErrorsRequest',
  full_name='google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1059,
  serialized_end=1158,
)


_LISTCAMPAIGNDRAFTASYNCERRORSRESPONSE = _descriptor.Descriptor(
  name='ListCampaignDraftAsyncErrorsResponse',
  full_name='google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsResponse.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1160,
  serialized_end=1259,
)

_MUTATECAMPAIGNDRAFTSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNDRAFTOPERATION
_CAMPAIGNDRAFTOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CAMPAIGNDRAFTOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2._CAMPAIGNDRAFT
_CAMPAIGNDRAFTOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2._CAMPAIGNDRAFT
_CAMPAIGNDRAFTOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNDRAFTOPERATION.fields_by_name['create'])
_CAMPAIGNDRAFTOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNDRAFTOPERATION.oneofs_by_name['operation']
_CAMPAIGNDRAFTOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNDRAFTOPERATION.fields_by_name['update'])
_CAMPAIGNDRAFTOPERATION.fields_by_name['update'].containing_oneof = _CAMPAIGNDRAFTOPERATION.oneofs_by_name['operation']
_CAMPAIGNDRAFTOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNDRAFTOPERATION.fields_by_name['remove'])
_CAMPAIGNDRAFTOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNDRAFTOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNDRAFTSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATECAMPAIGNDRAFTSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNDRAFTRESULT
_LISTCAMPAIGNDRAFTASYNCERRORSRESPONSE.fields_by_name['errors'].message_type = google_dot_rpc_dot_status__pb2._STATUS
DESCRIPTOR.message_types_by_name['GetCampaignDraftRequest'] = _GETCAMPAIGNDRAFTREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignDraftsRequest'] = _MUTATECAMPAIGNDRAFTSREQUEST
DESCRIPTOR.message_types_by_name['PromoteCampaignDraftRequest'] = _PROMOTECAMPAIGNDRAFTREQUEST
DESCRIPTOR.message_types_by_name['CampaignDraftOperation'] = _CAMPAIGNDRAFTOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignDraftsResponse'] = _MUTATECAMPAIGNDRAFTSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignDraftResult'] = _MUTATECAMPAIGNDRAFTRESULT
DESCRIPTOR.message_types_by_name['ListCampaignDraftAsyncErrorsRequest'] = _LISTCAMPAIGNDRAFTASYNCERRORSREQUEST
DESCRIPTOR.message_types_by_name['ListCampaignDraftAsyncErrorsResponse'] = _LISTCAMPAIGNDRAFTASYNCERRORSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignDraftRequest = _reflection.GeneratedProtocolMessageType('GetCampaignDraftRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNDRAFTREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignDraftService.GetCampaignDraft][google.ads.googleads.v2.services.CampaignDraftService.GetCampaignDraft].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign draft to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetCampaignDraftRequest)
  ))
_sym_db.RegisterMessage(GetCampaignDraftRequest)

MutateCampaignDraftsRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignDraftsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNDRAFTSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignDraftService.MutateCampaignDrafts][google.ads.googleads.v2.services.CampaignDraftService.MutateCampaignDrafts].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose campaign drafts are being
          modified.
      operations:
          The list of operations to perform on individual campaign
          drafts.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateCampaignDraftsRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignDraftsRequest)

PromoteCampaignDraftRequest = _reflection.GeneratedProtocolMessageType('PromoteCampaignDraftRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROMOTECAMPAIGNDRAFTREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignDraftService.PromoteCampaignDraft][google.ads.googleads.v2.services.CampaignDraftService.PromoteCampaignDraft].
  
  
  Attributes:
      campaign_draft:
          The resource name of the campaign draft to promote.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.PromoteCampaignDraftRequest)
  ))
_sym_db.RegisterMessage(PromoteCampaignDraftRequest)

CampaignDraftOperation = _reflection.GeneratedProtocolMessageType('CampaignDraftOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNDRAFTOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a campaign draft.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          campaign draft.
      update:
          Update operation: The campaign draft is expected to have a
          valid resource name.
      remove:
          Remove operation: The campaign draft is expected to have a
          valid resource name, in this format:  ``customers/{customer_id
          }/campaignDrafts/{base_campaign_id}~{draft_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.CampaignDraftOperation)
  ))
_sym_db.RegisterMessage(CampaignDraftOperation)

MutateCampaignDraftsResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignDraftsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNDRAFTSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """Response message for campaign draft mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateCampaignDraftsResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignDraftsResponse)

MutateCampaignDraftResult = _reflection.GeneratedProtocolMessageType('MutateCampaignDraftResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNDRAFTRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """The result for the campaign draft mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateCampaignDraftResult)
  ))
_sym_db.RegisterMessage(MutateCampaignDraftResult)

ListCampaignDraftAsyncErrorsRequest = _reflection.GeneratedProtocolMessageType('ListCampaignDraftAsyncErrorsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTCAMPAIGNDRAFTASYNCERRORSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignDraftService.ListCampaignDraftAsyncErrors][google.ads.googleads.v2.services.CampaignDraftService.ListCampaignDraftAsyncErrors].
  
  
  Attributes:
      resource_name:
          The name of the campaign draft from which to retrieve the
          async errors.
      page_token:
          Token of the page to retrieve. If not specified, the first
          page of results will be returned. Use the value obtained from
          ``next_page_token`` in the previous response in order to
          request the next page of results.
      page_size:
          Number of elements to retrieve in a single page. When a page
          request is too large, the server may decide to further limit
          the number of returned resources.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsRequest)
  ))
_sym_db.RegisterMessage(ListCampaignDraftAsyncErrorsRequest)

ListCampaignDraftAsyncErrorsResponse = _reflection.GeneratedProtocolMessageType('ListCampaignDraftAsyncErrorsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCAMPAIGNDRAFTASYNCERRORSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.campaign_draft_service_pb2'
  ,
  __doc__ = """Response message for
  [CampaignDraftService.ListCampaignDraftAsyncErrors][google.ads.googleads.v2.services.CampaignDraftService.ListCampaignDraftAsyncErrors].
  
  
  Attributes:
      errors:
          Details of the errors when performing the asynchronous
          operation.
      next_page_token:
          Pagination token used to retrieve the next page of results.
          Pass the content of this string as the ``page_token``
          attribute of the next request. ``next_page_token`` is not
          returned for the last page.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListCampaignDraftAsyncErrorsResponse)
  ))
_sym_db.RegisterMessage(ListCampaignDraftAsyncErrorsResponse)


DESCRIPTOR._options = None

_CAMPAIGNDRAFTSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignDraftService',
  full_name='google.ads.googleads.v2.services.CampaignDraftService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=1262,
  serialized_end=2182,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignDraft',
    full_name='google.ads.googleads.v2.services.CampaignDraftService.GetCampaignDraft',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNDRAFTREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2._CAMPAIGNDRAFT,
    serialized_options=_b('\202\323\344\223\0022\0220/v2/{resource_name=customers/*/campaignDrafts/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignDrafts',
    full_name='google.ads.googleads.v2.services.CampaignDraftService.MutateCampaignDrafts',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNDRAFTSREQUEST,
    output_type=_MUTATECAMPAIGNDRAFTSRESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v2/customers/{customer_id=*}/campaignDrafts:mutate:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='PromoteCampaignDraft',
    full_name='google.ads.googleads.v2.services.CampaignDraftService.PromoteCampaignDraft',
    index=2,
    containing_service=None,
    input_type=_PROMOTECAMPAIGNDRAFTREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=_b('\202\323\344\223\002>\"9/v2/{campaign_draft=customers/*/campaignDrafts/*}:promote:\001*\312A\027\n\025google.protobuf.Empty'),
  ),
  _descriptor.MethodDescriptor(
    name='ListCampaignDraftAsyncErrors',
    full_name='google.ads.googleads.v2.services.CampaignDraftService.ListCampaignDraftAsyncErrors',
    index=3,
    containing_service=None,
    input_type=_LISTCAMPAIGNDRAFTASYNCERRORSREQUEST,
    output_type=_LISTCAMPAIGNDRAFTASYNCERRORSRESPONSE,
    serialized_options=_b('\202\323\344\223\002B\022@/v2/{resource_name=customers/*/campaignDrafts/*}:listAsyncErrors'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNDRAFTSERVICE)

DESCRIPTOR.services_by_name['CampaignDraftService'] = _CAMPAIGNDRAFTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/frequency_cap.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import frequency_cap_event_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__event__type__pb2
from google.ads.google_ads.v1.proto.enums import frequency_cap_level_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__level__pb2
from google.ads.google_ads.v1.proto.enums import frequency_cap_time_unit_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__time__unit__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/frequency_cap.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\021FrequencyCapProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n8google/ads/googleads_v1/proto/common/frequency_cap.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x42google/ads/googleads_v1/proto/enums/frequency_cap_event_type.proto\x1a=google/ads/googleads_v1/proto/enums/frequency_cap_level.proto\x1a\x41google/ads/googleads_v1/proto/enums/frequency_cap_time_unit.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"{\n\x11\x46requencyCapEntry\x12<\n\x03key\x18\x01 \x01(\x0b\x32/.google.ads.googleads.v1.common.FrequencyCapKey\x12(\n\x03\x63\x61p\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xdf\x02\n\x0f\x46requencyCapKey\x12U\n\x05level\x18\x01 \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.FrequencyCapLevelEnum.FrequencyCapLevel\x12\x62\n\nevent_type\x18\x03 \x01(\x0e\x32N.google.ads.googleads.v1.enums.FrequencyCapEventTypeEnum.FrequencyCapEventType\x12_\n\ttime_unit\x18\x02 \x01(\x0e\x32L.google.ads.googleads.v1.enums.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit\x12\x30\n\x0btime_length\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\xec\x01\n\"com.google.ads.googleads.v1.commonB\x11\x46requencyCapProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__event__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__level__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__time__unit__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_FREQUENCYCAPENTRY = _descriptor.Descriptor(
  name='FrequencyCapEntry',
  full_name='google.ads.googleads.v1.common.FrequencyCapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.ads.googleads.v1.common.FrequencyCapEntry.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cap', full_name='google.ads.googleads.v1.common.FrequencyCapEntry.cap', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=475,
)


_FREQUENCYCAPKEY = _descriptor.Descriptor(
  name='FrequencyCapKey',
  full_name='google.ads.googleads.v1.common.FrequencyCapKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='google.ads.googleads.v1.common.FrequencyCapKey.level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='google.ads.googleads.v1.common.FrequencyCapKey.event_type', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_unit', full_name='google.ads.googleads.v1.common.FrequencyCapKey.time_unit', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_length', full_name='google.ads.googleads.v1.common.FrequencyCapKey.time_length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=829,
)

_FREQUENCYCAPENTRY.fields_by_name['key'].message_type = _FREQUENCYCAPKEY
_FREQUENCYCAPENTRY.fields_by_name['cap'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_FREQUENCYCAPKEY.fields_by_name['level'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__level__pb2._FREQUENCYCAPLEVELENUM_FREQUENCYCAPLEVEL
_FREQUENCYCAPKEY.fields_by_name['event_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__event__type__pb2._FREQUENCYCAPEVENTTYPEENUM_FREQUENCYCAPEVENTTYPE
_FREQUENCYCAPKEY.fields_by_name['time_unit'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_frequency__cap__time__unit__pb2._FREQUENCYCAPTIMEUNITENUM_FREQUENCYCAPTIMEUNIT
_FREQUENCYCAPKEY.fields_by_name['time_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
DESCRIPTOR.message_types_by_name['FrequencyCapEntry'] = _FREQUENCYCAPENTRY
DESCRIPTOR.message_types_by_name['FrequencyCapKey'] = _FREQUENCYCAPKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FrequencyCapEntry = _reflection.GeneratedProtocolMessageType('FrequencyCapEntry', (_message.Message,), dict(
  DESCRIPTOR = _FREQUENCYCAPENTRY,
  __module__ = 'google.ads.googleads_v1.proto.common.frequency_cap_pb2'
  ,
  __doc__ = """A rule specifying the maximum number of times an ad (or some set of ads)
  can be shown to a user over a particular time period.
  
  
  Attributes:
      key:
          The key of a particular frequency cap. There can be no more
          than one frequency cap with the same key.
      cap:
          Maximum number of events allowed during the time range by this
          cap.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.FrequencyCapEntry)
  ))
_sym_db.RegisterMessage(FrequencyCapEntry)

FrequencyCapKey = _reflection.GeneratedProtocolMessageType('FrequencyCapKey', (_message.Message,), dict(
  DESCRIPTOR = _FREQUENCYCAPKEY,
  __module__ = 'google.ads.googleads_v1.proto.common.frequency_cap_pb2'
  ,
  __doc__ = """A group of fields used as keys for a frequency cap. There can be no more
  than one frequency cap with the same key.
  
  
  Attributes:
      level:
          The level on which the cap is to be applied (e.g. ad group ad,
          ad group). The cap is applied to all the entities of this
          level.
      event_type:
          The type of event that the cap applies to (e.g. impression).
      time_unit:
          Unit of time the cap is defined at (e.g. day, week).
      time_length:
          Number of time units the cap lasts.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.FrequencyCapKey)
  ))
_sym_db.RegisterMessage(FrequencyCapKey)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
